@@ -1,4 +1,5 @@
 pub use chrono;
+pub use cloud_pubsub;
 pub use dropshot;
 pub use http;
 
@@ -14,7 +15,6 @@ pub mod money;
 pub mod payment;
 pub mod price;
 pub mod product;
-pub mod pubsub_server;
 pub mod server;
 pub mod shipping;
 pub mod transaction;
